@@ -15,6 +15,7 @@ import dai_python_commons.dai_error as dai_error
 from dai_python_commons.dai_error import DaiError
 from dai_python_commons.dai_error import S3BucketLocation
 from dai_python_commons.s3_utils import S3Utils
+from dai_python_commons.event_bridge import EventBridgeS3Event
 
 
 class ObjectEqualityStrategy(Enum):
@@ -197,7 +198,7 @@ class S3EventObjectCopy:
             result = next(iter(response.get("Contents", [])), None)
         # The boto3 exception mechanisms seems pretty badly documented so I use Exception to be on the safe side
         except Exception as the_exception:
-            self.logger.opt(exception=True).warning(
+            self.logger.warning(
                 f"Unable to get information about object {bucket}/{prefix}, error: {the_exception}")
 
         return result
@@ -452,3 +453,21 @@ class S3EventObjectCopy:
                 raise
 
         return num_records_copied
+
+    def copy_objects_event_bridge_s3_event(self, event: EventBridgeS3Event, destination_tags: Dict[str, any] = None) -> int:
+        source_bucket_name = event.s3_bucket
+        # needed to handle special characters
+        source_key = unquote_plus(event.s3_key)
+
+        self.logger.info(f"Copying object s3://{source_bucket_name}/{source_key} to bucket {self.destination_bucket}")
+
+        if source_bucket_name == self.destination_bucket:
+            incorrect_inputs = {"destination_bucket_name": self.destination_bucket}
+            raise dai_error.IncorrectInputValueError(
+                incorrect_inputs, "The destination bucket cannot be the same as the source bucket.")
+
+        self._copy_one_object(
+            source_bucket_name=source_bucket_name,
+            source_object=source_key,
+            destination_tags=destination_tags
+        )
